(tutorials)=

# Tutorials

The tutorials in this section are automatically executed with every change of
the code to make sure that they are always up-to-date.

<!-- To execute a tutorial on your own, you can click on the buttons at the top right
or this page to launch the notebook using [Binder](https://mybinder.org),
[Colab](https://colab.research.google.com), or download the `.ipynb` file
directly. -->

## Getting Started

```{toctree}
:maxdepth: 1
tutorials/quickstart
```

## Introductory Topics

```{toctree}
:maxdepth: 1

tutorials/introssm
tutorials/integrated
tutorials/kernels
tutorials/optimizing
tutorials/parallel
```

## Advanced Topics

```{toctree}
:maxdepth: 1

tutorials/derivative
tutorials/multivariate
tutorials/multicomponent
tutorials/multiinstrument
tutorials/multidimensional
tutorials/spatiotemporal
```